Focused JSON parsing and encoding for Blazingly protocol workloads.
Re-exports
pub use value::from_value;pub use value::Value;pub use value::ValueIndex;
Modules
Macros
Structs
- Canonical
Bytes Scanner - A zero-allocation canonical-layout recognizer over raw bytes.
- Canonical
Scanner - A zero-allocation recognizer for a known canonical JSON layout.
- Deserializer
- A zero-copy Serde deserializer over a UTF-8 JSON slice.
- Error
- Error returned while parsing or encoding JSON.
- Field
- One object member. The value must be consumed with one of this type’s methods before requesting the next field.
- Json
Cursor - A low-level, allocation-free cursor for routing selected object fields.
- Map
- Ordered object storage used by
crate::Value. - Number
- A finite JSON number represented without losing signed or unsigned integers.
- Object
- Streaming view over one JSON object visited by
JsonCursor::object. - RawJson
- A validated JSON value borrowed directly from the input buffer.
- RawValue
- A reference to one complete, validated JSON value.
- Serializer
- Streaming JSON serializer.
Functions
- from_
slice - Deserializes one complete JSON value from a byte slice.
- from_
str - Deserializes one complete JSON value from a string.
- to_
raw_ value - Serializes a value once and retains the resulting JSON verbatim.
- to_
string - Serializes a value into a compact UTF-8 string.
- to_
string_ pretty - Serializes a value into a pretty-printed UTF-8 string.
- to_
value - Serializes directly into an owned
Valuewithout an intermediate string. - to_vec
- Serializes a value into a compact byte vector.
- to_
vec_ pretty - Serializes a value into a pretty-printed byte vector.
- to_
writer - Serializes a value into an output writer.
Type Aliases
- Result
- Result alias used by this crate.